@@ -512,6 +512,11 @@ static void GetCertificateAndKey(server_rec *s,SSLConfigRec *pConfig)
 
 #if SSLEAY_VERSION_NUMBER >= 0x0800
     SSL_CTX_set_tmp_rsa_callback(pConfig->pSSLCtx,TmpRSACallback);
+    /* Really this should have its own directive and list, but I haven't got
+       the time at the moment.
+     */
+    SSL_CTX_set_client_CA_list(pConfig->pSSLCtx, 
+	    SSL_load_client_CA_file(pConfig->szCACertificateFile)); 
 #endif
     }
 
